@@ -4,6 +4,8 @@ from .default import DefaultClient
 from .sharded import ShardClient
 from .herd import HerdClient
 from .experimental import SimpleFailoverClient
+from .sentinel import SentinelClient
 
 __all__ = ['DefaultClient', 'ShardClient',
-           'HerdClient', 'SimpleFailoverClient']
+           'HerdClient', 'SimpleFailoverClient',
+           'SentinelClient']
